@@ -345,8 +345,10 @@ class Suite:
         Helper function for running tests written into cells.
         """
         code_source = "\n" + cell
-        name_cell = get_ipython().compile.cache(code_source)
-        exec(compile(code_source, name_cell, "exec"))
+        ipython = get_ipython()
+        name_cell = ipython.compile.cache(code_source)
+        code = compile(code_source, name_cell, "exec")
+        exec(code, ipython.user_global_ns, ipython.user_ns)
 
     def _test_cell(self, line: str, cell: Optional[str]) -> None:
         """
